@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import List, Optional, cast
 
 import requests
 
@@ -10,13 +10,21 @@ class GetLikeInfo(BaseVerseRequests):
     def get_like_all(self) -> List[LikeInfo]:
         res = requests.get(url=self.get_endpoint("/like/all"))
         self.validate_response(res)
-        return res.json()
+        res_like = res.json()
+        if res_like is list:
+            return cast(List[LikeInfo], res_like)
+        else:
+            raise ValueError("response is empty.")
 
     def get_like(self, post_id: str) -> LikeInfo:
         self.validate_parameter(post_id, 36, 36, "text_id")
         res = requests.get(url=self.get_endpoint("/like/" + post_id))
         self.validate_response(res)
-        return res.json()
+        res_like = res.json()
+        if type(res_like) is dict:
+            return cast(LikeInfo, res_like)
+        else:
+            raise ValueError("response is empty.")
 
     def get_like_OData(
         self,
@@ -38,4 +46,8 @@ class GetLikeInfo(BaseVerseRequests):
             params["$skip"] = str(skip)
         res = requests.get(self.URL + "/like/all", params=params)
         self.validate_response(res)
-        return res.json()
+        res_like = res.json()
+        if type(res_like) is list:
+            return cast(List[LikeInfo], res_like)
+        else:
+            raise ValueError("response is empty.")
