@@ -7,16 +7,14 @@ from typing import Any, List, Optional
 
 from prompt_toolkit.shortcuts import prompt
 
-from simpleverse import (
-    CreateLike,
-    CreateUser,
-    GetImageInfo,
-    GetLikeInfo,
-    GetPostInfo,
-    GetUserInfo,
-    SubmitImage,
-    SubmitPost,
-)
+from .create_like import CreateLike
+from .create_user import CreateUser
+from .get_image import GetImageInfo
+from .get_like import GetLikeInfo
+from .get_post import GetPostInfo
+from .get_user import GetUserInfo
+from .submit_image import SubmitImage
+from .submit_post import SubmitPost
 
 
 def pprint_json(json_obj: Any) -> None:
