@@ -34,6 +34,9 @@ class SubmitPost(BaseVerseRequests):
             headers={"Authorization": "HelloWorld"},
         )
         self.validate_response(res)
-        res_id = res.json()["id"]
+        res_id = res.json()
         # self.__set_own_id(res_id)
-        return res_id
+        if "id" in res_id:
+            return str(res_id["id"])
+        else:
+            raise ValueError("'id' is missing in response.")
